@@ -1,11 +1,12 @@
+use 5.010; # Perl 5.10+ needed for PDL/PDLA
 use strict;
 use warnings;
 package BenchmarkAnything::Evaluations;
-BEGIN {
-  $BenchmarkAnything::Evaluations::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.002-3-g453b389
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Evaluation support for BenchmarkAnything data
-$BenchmarkAnything::Evaluations::VERSION = '0.002';
+$BenchmarkAnything::Evaluations::VERSION = '0.003';
 use PDLA::Core;
 use PDLA::Stats;
 use PDLA::Ufunc;
@@ -40,6 +41,7 @@ sub transform_chartlines
         my $verbose     = $options->{verbose};
         my $debug       = $options->{debug};
         my $dropnull    = $options->{dropnull};
+        my $rawnumbers  = "";
 
         # from all chartlines collect values into buckets for the dimensions we need
         #
@@ -63,7 +65,10 @@ sub transform_chartlines
                 }
                 push @titles, $title;
 
-                print STDERR sprintf("* %-20s - %-40s\n", $title, $NAME) if $verbose;
+                my $rawline = sprintf("* %-20s - %-40s\n", $title, $NAME);
+                print STDERR $rawline if $verbose;
+                $rawnumbers.=$rawline;
+
                 print STDERR "  VALUE_IDs: ".join(",", map {$_->{VALUE_ID}} @$results)."\n" if $debug;
 
         POINT:
@@ -137,7 +142,9 @@ sub transform_chartlines
                         my $stdv  = $VALUES{$title}{$x}{stats}{stdv};
                         my $ci95l = $VALUES{$title}{$x}{stats}{ci_95_lower};
                         my $ci95u = $VALUES{$title}{$x}{stats}{ci_95_upper};
-                        print STDERR sprintf("  %-20s . %-7s . (ci95l..avg..ci95u) = (%2.2f .. %2.2f .. %2.2f) +- stdv %5.2f (%3d points)\n", $title, $x, $ci95l, $avg, $ci95u, $stdv, $count) if $verbose;
+                        my $rawline = sprintf("  %-20s . %-7s . (ci95l..avg..ci95u) = (%2.2f .. %2.2f .. %2.2f) +- stdv %5.2f (%3d points)\n", $title, $x, $ci95l, $avg, $ci95u, $stdv, $count);
+                        $rawnumbers .= $rawline;
+                        print STDERR $rawline if $verbose;
                 }
         }
 
@@ -161,7 +168,12 @@ sub transform_chartlines
                         $RESULTMATRIX[$i+1] [$j+1] = $value;
                 }
         }
-        return \@RESULTMATRIX;
+
+        if (wantarray) {
+                return (\@RESULTMATRIX, $rawnumbers);
+        } else {
+                return \@RESULTMATRIX;
+        }
 }
 
 1;
@@ -246,7 +258,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
